<?php

namespace Drupal\yasm\Utility;

use Drupal\group\Entity\GroupInterface;
use Drupal\node\Entity\NodeType;

/**
 * Groups statistics class.
 */
class GroupsStatistics {

  /**
   * Count group contents.
   */
  public static function countContents(GroupInterface $group) {
    // Use static query for performance.
    $query = \Drupal::database()
      ->query('SELECT count(id) as count FROM {group_content_field_data} WHERE gid = :id AND type LIKE :type', [
        ':id' => $group->id(),
        ':type' => $group->getGroupType()->id() . '-group_node-%',
      ]);
    $result = $query->fetchAll();

    return $result[0]->count;
  }

  /**
   * Count group contents grouping by content type.
   */
  public static function countContentsByType(GroupInterface $group) {
    // Use static query for performance.
    $query = \Drupal::database()
      ->query('SELECT count(id) as count, type FROM {group_content_field_data} WHERE gid = :id AND type LIKE :type GROUP by type', [
        ':id' => $group->id(),
        ':type' => $group->getGroupType()->id() . '-group_node-%',
      ]);
    $results = $query->fetchAll();

    $count_types = [];
    if (!empty($results)) {
      $content_types = NodeType::loadMultiple();

      foreach ($results as $result) {
        if (isset($result->type)) {
          $ctype = (string) $result->type;
          $ctype = substr($ctype, strrpos($ctype, '-') + 1);
          $count_types[$ctype] = [
            'type'  => isset($content_types[$ctype]) ? $content_types[$ctype]->label() : $ctype,
            'count' => $result->count,
          ];
        }
      }
    }

    return $count_types;
  }

  /**
   * Count group members.
   */
  public static function countMembers(GroupInterface $group) {
    // Use static query for performance.
    $query = \Drupal::database()
      ->query('SELECT count(id) as count FROM {group_content_field_data} WHERE gid = :id AND type = :type', [
        ':id' => $group->id(),
        ':type' => $group->getGroupType()->id() . '-group_membership',
      ]);
    $result = $query->fetchAll();

    return $result[0]->count;
  }

}
